@@ -42,7 +42,7 @@ Storage::Storage(QObject* parent)
 
 }
 
-Storage::Storage(const QString databasePath, QObject* parent)
+Storage::Storage(const QString &databasePath, QObject* parent)
     : QObject(parent)
     , m_databasePath(databasePath)
     , m_errorMessage(QString())
@@ -57,7 +57,7 @@ QString Storage::errorMessage() const
 
 void Storage::raiseError(const QSqlError &error)
 {
-    m_errorMessage = QStringLiteral("%1 : %2").arg(error.driverText()).arg(error.databaseText());
+    m_errorMessage = QStringLiteral("%1 : %2").arg(error.driverText(), error.databaseText());
     emit errorMessageChanged();
 }
 
