@@ -22,22 +22,23 @@
 #define UNIT_H
 
 #include "artikulatecore_export.h"
-#include "phrase.h"
+#include <memory>
 #include <QObject>
 #include <QList>
+#include <QVector>
 #include <QStringList>
 
 class QSignalMapper;
 class QString;
 class Phrase;
-class Course;
+class ICourse;
 
 class ARTIKULATECORE_EXPORT Unit : public QObject
 {
     Q_OBJECT
     Q_PROPERTY(QString id READ id WRITE setId NOTIFY idChanged)
     Q_PROPERTY(QString title READ title WRITE setTitle NOTIFY titleChanged)
-    Q_PROPERTY(Course *course READ course WRITE setCourse NOTIFY courseChanged)
+    Q_PROPERTY(ICourse *course READ course WRITE setCourse NOTIFY courseChanged)
 
 public:
     explicit Unit(QObject *parent = nullptr);
@@ -47,11 +48,11 @@ public:
     void setId(const QString &id);
     QString foreignId() const;
     void setForeignId(const QString &id);
-    Course * course() const;
-    void setCourse(Course* course);
+    ICourse * course() const;
+    void setCourse(ICourse* course);
     QString title() const;
     void setTitle(const QString &title);
-    QList<Phrase *> phraseList() const;
+    QList<Phrase*> phraseList() const;
     void addPhrase(Phrase *phrase);
     QList<Phrase *> excludedSkeletonPhraseList() const;
 
@@ -70,10 +71,8 @@ Q_SIGNALS:
     void courseChanged();
     void displayPhraseTypeChanged();
     void modified();
-    void phraseAdded();
     void phraseAdded(Phrase*);
     void phraseAboutToBeAdded(Phrase*,int);
-    void phraseRemoved();
     void phraseRemoved(Phrase*);
     void phraseAboutToBeRemoved(int,int);
 
@@ -81,9 +80,9 @@ private:
     Q_DISABLE_COPY(Unit)
     QString m_id;
     QString m_foreignId;
-    Course *m_course;
+    ICourse *m_course;
     QString m_title;
-    QList<Phrase *> m_phraseList;
+    QList<Phrase*> m_phrases;
     QSignalMapper *m_phraseSignalMapper;
 };
 
