@@ -19,7 +19,7 @@
  */
 
 #include "phonemeunitmodel.h"
-#include "core/course.h"
+#include "core/icourse.h"
 #include "core/unit.h"
 #include "core/phonemegroup.h"
 
@@ -52,7 +52,7 @@ QHash< int, QByteArray > PhonemeUnitModel::roleNames() const
     return roles;
 }
 
-void PhonemeUnitModel::setCourse(Course *course)
+void PhonemeUnitModel::setCourse(ICourse *course)
 {
     if (m_course == course) {
         return;
@@ -66,12 +66,13 @@ void PhonemeUnitModel::setCourse(Course *course)
 
     m_course = course;
 
-    if (m_course) {
-        connect(m_course, &Course::phonemeGroupAboutToBeAdded, this, &PhonemeUnitModel::onUnitAboutToBeAdded);
-        connect(m_course, &Course::phonemeGroupAdded, this, &PhonemeUnitModel::onUnitAdded);
-        connect(m_course, &Course::phonemeGroupAboutToBeRemoved, this, &PhonemeUnitModel::onUnitsAboutToBeRemoved);
-        connect(m_course, &Course::phonemeGroupRemoved, this, &PhonemeUnitModel::onUnitsRemoved);
-    }
+    // TODO currently no phonems supported in icourse
+//    if (m_course) {
+//        connect(m_course, &Course::phonemeGroupAboutToBeAdded, this, &PhonemeUnitModel::onUnitAboutToBeAdded);
+//        connect(m_course, &Course::phonemeGroupAdded, this, &PhonemeUnitModel::onUnitAdded);
+//        connect(m_course, &Course::phonemeGroupAboutToBeRemoved, this, &PhonemeUnitModel::onUnitsAboutToBeRemoved);
+//        connect(m_course, &Course::phonemeGroupRemoved, this, &PhonemeUnitModel::onUnitsRemoved);
+//    }
 
     endResetModel();
 
@@ -95,59 +96,63 @@ PhonemeGroup* PhonemeUnitModel::phonemeGroup() const
     return m_phonemeGroup;
 }
 
-Course * PhonemeUnitModel::course() const
+ICourse * PhonemeUnitModel::course() const
 {
     return m_course;
 }
 
 QVariant PhonemeUnitModel::data(const QModelIndex& index, int role) const
 {
-    Q_ASSERT(m_course);
-    Q_ASSERT(m_phonemeGroup);
+     //TODO currently no phonems supported
+    return QVariant();
+//    Q_ASSERT(m_course);
+//    Q_ASSERT(m_phonemeGroup);
 
-    if (!index.isValid()) {
-        return QVariant();
-    }
+//    if (!index.isValid()) {
+//        return QVariant();
+//    }
 
-    if (index.row() >= m_course->phonemeUnitList(m_phonemeGroup).count()) {
-        return QVariant();
-    }
+//    if (index.row() >= m_course->phonemeUnitList(m_phonemeGroup).count()) {
+//        return QVariant();
+//    }
 
-    Unit * const unit = m_course->phonemeUnitList(m_phonemeGroup).at(index.row());
+//    Unit * const unit = m_course->phonemeUnitList(m_phonemeGroup).at(index.row());
 
-    switch(role)
-    {
-    case Qt::DisplayRole:
-        return !unit->title().isEmpty()?
-                QVariant(unit->title()): QVariant(i18nc("@item:inlistbox:", "unknown"));
-    case Qt::ToolTipRole:
-        return QVariant(unit->title());
-    case TitleRole:
-        return unit->title();
-    case NumberPhrasesRole:
-        return unit->phraseList().count();
-    case IdRole:
-        return unit->id();
-    case DataRole:
-        return QVariant::fromValue<QObject*>(unit);
-    case PhonemeGroupRole:
-        return QVariant::fromValue<QObject*>(m_course->phonemeGroup(unit));
-    default:
-        return QVariant();
-    }
+//    switch(role)
+//    {
+//    case Qt::DisplayRole:
+//        return !unit->title().isEmpty()?
+//                QVariant(unit->title()): QVariant(i18nc("@item:inlistbox:", "unknown"));
+//    case Qt::ToolTipRole:
+//        return QVariant(unit->title());
+//    case TitleRole:
+//        return unit->title();
+//    case NumberPhrasesRole:
+//        return unit->phraseList().count();
+//    case IdRole:
+//        return unit->id();
+//    case DataRole:
+//        return QVariant::fromValue<QObject*>(unit);
+//    case PhonemeGroupRole:
+//        return QVariant::fromValue<QObject*>(m_course->phonemeGroup(unit));
+//    default:
+//        return QVariant();
+//    }
 }
 
 int PhonemeUnitModel::rowCount(const QModelIndex& parent) const
 {
-    if (!m_course) {
-        return 0;
-    }
+    // TODO currently no phonems supported in icourse
+    return 0;
+//    if (!m_course) {
+//        return 0;
+//    }
 
-    if (parent.isValid()) {
-        return 0;
-    }
+//    if (parent.isValid()) {
+//        return 0;
+//    }
 
-    return m_course->phonemeUnitList(m_phonemeGroup).count();
+//    return m_course->phonemeUnitList(m_phonemeGroup).count();
 }
 
 void PhonemeUnitModel::onUnitAboutToBeAdded(PhonemeGroup *phonemeGroup, int index)
@@ -194,16 +199,18 @@ QVariant PhonemeUnitModel::headerData(int section, Qt::Orientation orientation,
 
 int PhonemeUnitModel::count() const
 {
-    if (!m_course || !m_phonemeGroup) {
-        return 0;
-    }
-    return m_course->phonemeUnitList(m_phonemeGroup).count();
+    // TODO currently no phonems supported
+    return 0;
+//    if (!m_course || !m_phonemeGroup) {
+//        return 0;
+//    }
+//    return m_course->phonemeUnitList(m_phonemeGroup).count();
 }
 
 void PhonemeUnitModel::updateMappings()
 {
-    int units = m_course->phonemeUnitList(m_phonemeGroup).count();
-    for (int i = 0; i < units; i++) {
-        m_signalMapper->setMapping(m_course->phonemeUnitList(m_phonemeGroup).at(i), i);
-    }
+//    int units = m_course->phonemeUnitList(m_phonemeGroup).count();
+//    for (int i = 0; i < units; i++) {
+//        m_signalMapper->setMapping(m_course->phonemeUnitList(m_phonemeGroup).at(i), i);
+//    }
 }
